@@ -1,9 +1,9 @@
 #
 # fields  is a package for analysis of spatial data written for
 # the R software environment.
-# Copyright (C) 2022 Colorado School of Mines
+# Copyright (C) 2024 Colorado School of Mines
 # 1500 Illinois St., Golden, CO 80401
-# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
+# Contact: Douglas Nychka,  douglasnychka@gmail.com,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -68,13 +68,17 @@ mKrigMLEGrid <- function(x, y, weights = rep(1, nrow(x)), Z = NULL,
   summary <-NULL
   # begin loop over covariance parameters and either evaluate at a grid of  lambda values
   # or use these as start values for optimization.
+  if( verbose){
+    cat( "******** Grid search in mKrigMLEGrid", fill=TRUE)
+    }
   for (k in 1:NG) {
     cov.args.temp <- as.list( par.grid[k, ])
     names(cov.args.temp) <- names( par.grid)
     currentCov.args<- c( cov.args.temp, cov.args) 
     if( verbose){
-      cat( "********grid value: " , k, fill=TRUE)
-      cat( "Cov args", names(currentCov.args ), fill=TRUE, sep=", ")
+      cat( "******** grid value: " , k, fill=TRUE)
+      cat( "Cov args", names(currentCov.args ), fill=TRUE,
+      sep=", ")
       cat("value  aRange", fill=TRUE)
       print( currentCov.args$aRange)
       cat("value  lambda", fill=TRUE)
