@@ -36,6 +36,11 @@ extern SEXP distMatHaversin2(SEXP, SEXP, SEXP, SEXP);
 
 /* .Fortran calls */
 extern void F77_NAME(css)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+
+extern void F77_NAME(dsetup)(void *, void *, void *, void *,
+			                       void *, void *, void *, void *, void * );
+extern void F77_NAME(dchold)(void *, void *, void *, void *,
+                             void *, void *, void * );
 extern void F77_NAME(ddfind)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(dmaket)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(evlpoly)(void *, void *, void *, void *, void *);
@@ -60,8 +65,12 @@ static const R_CallMethodDef CallEntries[] = {
     {NULL, NULL, 0}
 };
 
+
+
 static const R_FortranMethodDef FortranEntries[] = {
     {"css",           (DL_FUNC) &F77_NAME(css),           15},
+    {"dsetup",        (DL_FUNC) &F77_NAME(dsetup),         9},
+    {"dchold",        (DL_FUNC) &F77_NAME(dchold),         7},
     {"ddfind",        (DL_FUNC) &F77_NAME(ddfind),        10},
     {"dmaket",        (DL_FUNC) &F77_NAME(dmaket),        12},
     {"evlpoly",       (DL_FUNC) &F77_NAME(evlpoly),        5},
